@@ -1,4 +1,3 @@
-# $Id$
 #
 # BioPerl module for Bio::Tools::Run::Alignment::Kalign
 #
@@ -467,8 +466,9 @@ sub _setparams {
     }
     $param_string .= " -out ".$self->outfile_name;
     
-    if ($self->quiet() || $self->verbose < 0) { 
-	$param_string .= ' 2> /dev/null';
+    if ($self->quiet() || $self->verbose < 0) {
+	my $null = ($^O =~ m/mswin/i) ? 'NUL' : '/dev/null';
+	$param_string .= " 2> $null";
     }
     return $param_string;
 }
