@@ -1,4 +1,3 @@
-# $Id$
 # BioPerl module for FootPrinter
 #
 # Copyright Shawn Hoon
@@ -67,7 +66,7 @@ Written by Mathieu Blanchette and Martin Tompa. Available here:
 
 =head2 Running Footprinter
 
-To run FootPrinter, you will need to set the enviroment variable
+To run FootPrinter, you will need to set the environment variable
 FOOTPRINTER_DIR to where the binary is located (even if the executable
 is in your path). For example:
 
@@ -336,7 +335,8 @@ sub _run {
   $self->debug("FootPrinter command = $cmd_str");
 
   if ($self->verbose <=0){
-      $cmd_str.=" >&/dev/null > /dev/null";
+      my $null = ($^O =~ m/mswin/i) ? 'NUL' : '/dev/null';
+      $cmd_str.= " >&$null > $null";
   }
   
   # will do brute-force clean up of junk files generated by FootPrinter
@@ -545,5 +545,3 @@ sub _setinput {
 =cut
 
 1;
-
-
