@@ -1,4 +1,3 @@
-# $Id: Semphy.pm,v 1.3 2007/05/25 10:14:55 sendu Exp $
 #
 # BioPerl module for Bio::Tools::Run::Phylo::Semphy
 #
@@ -252,10 +251,10 @@ sub new {
            argument a species tree (to set an initial tree: normally the -t
            option to Semphy).
            The alignment can be provided as a multi-fasta format alignment
-           filename, or a Bio::Align::AlignI complient object (eg. a
+           filename, or a Bio::Align::AlignI compliant object (eg. a
            Bio::SimpleAlign).
            The species tree can be provided as a newick format tree filename
-           or a Bio::Tree::TreeI complient object. Alternatively a
+           or a Bio::Tree::TreeI compliant object. Alternatively a
            Bio::DB::Taxonomy object can be supplied, in which case the species
            tree will be generated by using the alignment sequence names as
            species names and looking for those in the supplied database.
@@ -342,7 +341,8 @@ sub _setparams {
                                               -double_dash => 1);
     
     $param_string .= ' 2>&1';
-    $param_string .= ' 1>/dev/null' if $self->quiet;
+    my $null = ($^O =~ m/mswin/i) ? 'NUL' : '/dev/null';
+    $param_string .= " 1>$null" if $self->quiet;
     
     return $param_string;
 }
